@@ -25,7 +25,7 @@ class CaptureResponse(TypedDict, total=False):
     '''A capture made by Lacus. With the base64 encoded image and downloaded file decoded to bytes.'''
 
     status: int
-    last_redirected_url: str
+    last_redirected_url: Optional[str]
     har: Optional[Dict[str, Any]]
     cookies: Optional[List[Dict[str, str]]]
     error: Optional[str]
@@ -34,6 +34,7 @@ class CaptureResponse(TypedDict, total=False):
     downloaded_filename: Optional[str]
     downloaded_file: Optional[bytes]
     children: Optional[List[Any]]
+    runtime: Optional[float]
 
 
 class CaptureResponseJson(TypedDict, total=False):
@@ -49,6 +50,7 @@ class CaptureResponseJson(TypedDict, total=False):
     downloaded_filename: Optional[str]
     downloaded_file: Optional[str]
     children: Optional[List[Any]]
+    runtime: Optional[float]
 
 
 class CaptureSettings(TypedDict, total=False):
@@ -70,6 +72,7 @@ class CaptureSettings(TypedDict, total=False):
     force: Optional[bool]
     recapture_interval: Optional[int]
     priority: Optional[int]
+    uuid: Optional[str]
 
     depth: int
     rendered_hostname_only: bool  # Note: only used if depth is > 0
@@ -125,7 +128,8 @@ class PyLacus():
                 rendered_hostname_only: bool=True,
                 force: bool=False,
                 recapture_interval: int=300,
-                priority: int=0
+                priority: int=0,
+                uuid: Optional[str]=None,
                 ) -> str:
         ...
 
@@ -146,7 +150,8 @@ class PyLacus():
                 rendered_hostname_only: bool=True,
                 force: bool=False,
                 recapture_interval: int=300,
-                priority: int=0
+                priority: int=0,
+                uuid: Optional[str]=None,
                 ) -> str:
         '''Submit a new capture. Pass a typed dictionary or any of the relevant settings, get the UUID.'''
         to_enqueue: CaptureSettings
@@ -180,6 +185,8 @@ class PyLacus():
                 to_enqueue['viewport'] = viewport
             if referer:
                 to_enqueue['referer'] = referer
+            if uuid:
+                to_enqueue['uuid'] = uuid
 
         r = self.session.post(urljoin(self.root_url, 'enqueue'), json=to_enqueue)
         return r.json()
